==> haskell-tasty-sugar-2.2.2.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.2.1
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.2.1-LEeql0IVVSQG4U5YG7taVw-tasty-sugar-internal

key:
    tasty-sugar-2.2.2.1-LEeql0IVVSQG4U5YG7taVw-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  e35a1bec7aaa5ccaa0836075a8ab97e1
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.2.1-LEeql0IVVSQG4U5YG7taVw-tasty-sugar-internal

depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-ANP0sM8kVRq97gZCgLu5XP filepath-1.4.2.2
    kvitable-1.1.0.1-A26v9YMYOmt5Lu7mvR6ZrH
    logict-0.8.1.0-BJXYkpxvFYVL2f1qfqtOx4
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-Fh4Rajbxlmi9sLGTMcb6xB text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.2.1
visibility:           public
id:                   tasty-sugar-2.2.2.1-EKvEvFmajSe3280IN4lOBh
key:                  tasty-sugar-2.2.2.1-EKvEvFmajSe3280IN4lOBh
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  255b9ad2701e4cfed8bfa4e105acdd07
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.2.1-EKvEvFmajSe3280IN4lOBh
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-ANP0sM8kVRq97gZCgLu5XP filepath-1.4.2.2
    logict-0.8.1.0-BJXYkpxvFYVL2f1qfqtOx4
    optparse-applicative-0.18.1.0-Ebh0I8Iojv3DBRdzITzz2E
    prettyprinter-1.7.1-Fh4Rajbxlmi9sLGTMcb6xB
    tasty-1.5-1LVG3MTEaeV50BoWi4FIMR
    tasty-sugar-2.2.2.1-LEeql0IVVSQG4U5YG7taVw-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-sugar-2.2.2.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.2.1
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.2.1-Hce3HgWXBDB2qAbK1pvyLr-tasty-sugar-internal

key:
    tasty-sugar-2.2.2.1-Hce3HgWXBDB2qAbK1pvyLr-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  f84b75db47a4f105ceafdac26314d2c4
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.2.1-Hce3HgWXBDB2qAbK1pvyLr-tasty-sugar-internal

depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-CxqsSqr4Ot0cua2HGoJD5 filepath-1.4.2.2
    kvitable-1.1.0.1-Fy7n60ee01KLUfl85Q0Kts
    logict-0.8.1.0-36h0Y3Aop4cHwg19RQoVfD
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-9QhHPrVd9M8A9sreY2Uj3h text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.2.1
visibility:           public
id:                   tasty-sugar-2.2.2.1-9f8VZrVLogP44SVEQFHu2w
key:                  tasty-sugar-2.2.2.1-9f8VZrVLogP44SVEQFHu2w
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  2f6c9f1a29bc34a9e2ffe8c0d0a629d0
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.2.1-9f8VZrVLogP44SVEQFHu2w
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-CxqsSqr4Ot0cua2HGoJD5 filepath-1.4.2.2
    logict-0.8.1.0-36h0Y3Aop4cHwg19RQoVfD
    optparse-applicative-0.18.1.0-2d5KBqGSFxr6w2uOa2AvYP
    prettyprinter-1.7.1-9QhHPrVd9M8A9sreY2Uj3h
    tasty-1.5-EJAmunAt6abUkg0SfaENc
    tasty-sugar-2.2.2.1-Hce3HgWXBDB2qAbK1pvyLr-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
